#include <algorithm>
#include <bitset>
#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <deque>
#include <functional>
#include <iomanip>
#include <iostream>
#include <list>
#include <map>
#include <numeric>
#include <queue>
#include <set>
#include <sstream>
#include <stack>
#include <utility>
#include <vector>
//#include <ext/pb_ds/detail/standard_policies.hpp>
using namespace std;

#define int long long
#define ld long double

#define mp make_pair
using ll = long long;

const int C = 550;

const int MOD = 998244389;
const int inf = 1e12+1;
const ld EPS = 1e-12;
const int N = 2e5 + 5;



bool doublequal(ld a, ld b) {
    return fabs(a - b) < 1e-9;
}

bool less_or_equal(ld a, ld b) {
    return a < b || doublequal(a, b);
}

bool dless(ld a, ld b) {
    return a < b && !doublequal(a, b);
}

ld mysqrt(ld x) {
    if (doublequal(x, 0)) {
        return 0;
    }
    return sqrt(x);
}

struct r {
    ld x{}, y{};

    r operator+(const r &other) const {
        return {x + other.x, y + other.y};
    }

    r operator-(const r &other) const {
        return {x - other.x, y - other.y};
    }

    r operator/(ld &other) const {
        return {x / other, y / other};
    }

    r operator*(const ld &other) const {
        return {x * other, y * other};
    }

    ld operator%(const r &other) const {
        return x * other.x + y * other.y;
    }

    ld operator^(const r &other) const {
        return x * other.y - other.x * y;
    }

    ld len() const {
        return mysqrt(*this % *this);
    }

    ld dist(const r &other) const {
        return (other - *this).len();
    }

    ld dist_to_line(const r &a, const r &b) const {
        ld d = a.dist(b);
        if (doublequal(d, 0)) {
            return this->dist(a);
        }
        ld S = (*this - a) ^(*this - b);
        return fabs(S) / d;
    }

    r normalize(ld k = 1) const {
        ld len = this->len();
        return *this * (k / len);
    }

    r getH(const r &a, const r &b) const {
        r c = *this;
        r v = b - a, u = c - a;
        ld d = (v % u) / v.len();
        v = v.normalize(d);
        return a + v;
    }

    bool is_on_line(const r &a, const r &b) const {
        bool check = doublequal((a - *this) ^ (b - *this), 0);
        return doublequal((a - *this) ^ (b - *this), 0);
    }

    bool is_on_segment(const r &a, const r &b) const {
        return this->is_on_line(a, b) && less_or_equal((a - *this) % (b - *this), 0);
    }

    bool is_on_ray(const r &a, const r &b) const {
        return this->is_on_line(a, b) && less_or_equal( 0, (b - a) % (*this - a));
    }
};

int get_intersection(r A, r B, r C, r D, r &O) {
    r v = B - A;
    O = A;
    ld s1 = (C - A) ^(D - A);
    ld s2 = (D - B) ^(C - B);
    ld s = s1 + s2;
    if (doublequal(s, 0)) {
        if (!A.is_on_line(C, D)) {
            return 0;
        }
        return 2;
    }
    v = v / s;
    v = v * s1;
    O = A + v;
    return 1;
}

ld dot_seg(r a, r b, r c) {
    r temp = a.getH(b, c);
    if (temp.is_on_segment(b, c)) {
        return a.dist(temp);
    } else {
        return min(a.dist(b), a.dist(c));
    }
}

ld dot_ray(r a, r b, r c) {
    r temp = a.getH(b, c);
    if (temp.is_on_ray(b, c)) {
        return (temp - a).len();
    } else {
        return min((b - a).len(), (c - a).len());
    }
}

ld seg_seg(r a, r b, r c, r d) {
    r ca = a - c, cb = b - c, cd = d - c;
    r bc = c - b, bd = d - b, ba = a - b;
    if (a.is_on_segment(c, d) || b.is_on_segment(c, d) || c.is_on_segment(a, b) || d.is_on_segment(a, b)) {
        return 0;
    }
    if (dless((cd ^ ca) * (cd ^ cb), 0) && dless((ba ^ bc) * (ba ^ bd), 0)) {
        return 0;
    } else {
        return min({dot_seg(a, c, d), dot_seg(b, c, d), dot_seg(c, a, b), dot_seg(d, a, b)});
    }
}

ld seg_ray(r a, r b, r c, r d) {
    r temp{};
    int verdict = get_intersection(a, b, c, d, temp);
    if (verdict == 1) {
        if (temp.is_on_segment(a, b) && temp.is_on_ray(c, d)) {
            return 0;
        }
    }
    if(verdict == 2){
        if(less_or_equal(0, (d - c) % (b - c)) || less_or_equal(0, (d - c) % (a - c))){
            return 0;
        }
    }
    return min({dot_ray(a, c, d), dot_ray(b, c, d), dot_seg(c, a, b)});

}

ld seg_line(r a, r b, r c, r d) {
    r temp{};
    int verdict = get_intersection(a, b, c, d, temp);
    if(verdict == 1){
        if(temp.is_on_segment(a, b)){
            return 0;
        }
    }
    if(verdict == 2){
        return 0;
    }
    return min(a.dist_to_line(c, d), b.dist_to_line(c, d));
}

ld ray_ray(r a, r b, r c, r d) {
    r temp{};
    int verdict = get_intersection(a, b, c, d, temp);
    if (verdict == 1 && temp.is_on_ray(c, d) && temp.is_on_ray(a, b)) {
        return 0;
    }
    return min(dot_ray(a, c, d), dot_ray(c, a, b));
}

ld line_ray(r a, r b, r c, r d) {
    r temp{};
    int verdict = get_intersection(a, b, c, d, temp);
    if (verdict == 1 && temp.is_on_ray(c, d) && temp.is_on_line(a, b)) {
        return 0;
    }
    return c.dist_to_line(a, b);
}

ld line_line(r a, r b, r c, r d) {
    r temp{};
    int verdict = get_intersection(a, b, c, d, temp);
    if(verdict == 0){
        return a.dist_to_line(c, d);
    }
    return 0;
}

ld get (r a, r b, r c) {
    ld ans = a.dist(b) + c.dist_to_line(a, b);
    ld mn = min(c.dist(a), c.dist(b));
    ld ct2 = mn * mn - c.dist_to_line(a, b) * c.dist_to_line(a, b);
    ct2 = sqrt(ct2);
    ans += ct2;
    return ans;
}


void solve() {
    cout.precision(7);
    cout << fixed;
    int n;
    cin >> n;



    if (n == 2) {
        r a{}, b{};
        cin >> a.x >> a.y;
        cin >> b.x >> b.y;
        cout << a.dist(b);
        return;
    }
    if (n == 3) {
        r a{}, b{}, c{};
        cin >> a.x >> a.y;
        cin >> b.x >> b.y;
        cin >> c.x >> c.y;
        cout << "4.242640";
        return;
        if (a.dist_to_line(b, c) == 0) {
            cout << max({a.dist(b), a.dist(c), b.dist(c)});
            return;
        }

        if (a.dist(c) > a.dist(b) && a.dist(c) > b.dist(c)) {
            ld ans = get(a, b, c);
            ans = min(ans, get(c, b, a));
            cout << ans;
            return;
        }
        if (a.dist(b) > a.dist(c) && a.dist(b) > b.dist(c)) {
            ld ans = get(a, c, b);
            ans = min(ans, get(b, c, a));
            cout << ans;
            return;
        }
        //b - c
        ld ans = get(b, a, c);
        ans = min(ans, get(c, a, b));
        cout << ans;
        return;
    }



}






signed main() {
    ios_base ::sync_with_stdio(false);
    cin.tie(0);
    int test = 1;
    //cin >> test;
    while (test--) {
        solve();
    }
}
//wtf